OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Невозможно выполнить запись в каталог «config».",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Обычно это можно исправить, предоставив веб-серверу права на запись в каталог конфигурации",
    "See %s" : "Смотрите %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Или, если вы предпочитаете хранить файл config.php только для чтения, установите для него параметр «config_is_read_only» в true.",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в каталог конфигурации. Смотрите %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, если вы предпочитаете хранить файл config.php только для чтения, установите для него параметр «config_is_read_only» в true. Смотрите %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файлы приложения %1$s не были корректно заменены. Удостоверьтесь, что его версия совместима с версией сервера.",
    "Sample configuration detected" : "Обнаружена конфигурация из примера",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Была обнаружена конфигурация из примера. Такая конфигурация не поддерживается и может повредить вашей системе. Прочтите документацию перед внесением изменений в файл config.php",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Education Edition" : "Образовательная редакция",
    "Enterprise bundle" : "Корпоративный пакет",
    "Groupware bundle" : "Пакет для групп",
    "Social sharing bundle" : "Пакет для соц. сетей",
    "PHP %s or higher is required." : "Требуется PHP версии %s или выше.",
    "PHP with a version lower than %s is required." : "Требуется PHP версии ниже %s.",
    "%sbit or higher PHP required." : "Требуется PHP с разрядностью %s бит или более.",
    "Following databases are supported: %s" : "Поддерживаются следующие СУБД: %s",
    "The command line tool %s could not be found" : "Утилита командной строки %s не найдена",
    "The library %s is not available." : "Библиотека «%s» недоступна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Требуется библиотека «%1$s» версии не меньше %2$s, установлена версия %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Требуется библиотека «%1$s» версии не выше %2$s, установлена версия %3$s.",
    "Following platforms are supported: %s" : "Поддерживаются следующие платформы: %s",
    "Server version %s or higher is required." : "Требуется сервер версии %s или выше.",
    "Server version %s or lower is required." : "Требуется сервер версии %s или ниже.",
    "Logged in user must be an admin or sub admin" : "Вошедший в систему пользователь должен обладать правами администратора или суб-администратора",
    "Logged in user must be an admin" : "Залогинившийся пользователь должен быть администратором",
    "Wiping of device %s has started" : "Очистка устройства %s запущена",
    "Wiping of device »%s« has started" : "Очистка устройства «%s» запущена",
    "»%s« started remote wipe" : "«%s» запустило удаленную очистку",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Устройство или приложение «%s» запустило процесс удаленной очистки. После завершения процесса вы получите еще одно электронное письмо.",
    "Wiping of device %s has finished" : "Очистка устройства %s завершена",
    "Wiping of device »%s« has finished" : "Очистка устройства «%s» завершена",
    "»%s« finished remote wipe" : "«%s» завершило удаленную очистку",
    "Device or application »%s« has finished the remote wipe process." : "Устройство или приложение «%s» завершило процесс удаленной очистки.",
    "Remote wipe started" : "Удаленная очистка запущена",
    "A remote wipe was started on device %s" : "Удаленная очистка была запущена на устройстве %s",
    "Remote wipe finished" : "Удалённая очистка закончена",
    "The remote wipe on %s has finished" : "Удаленная очистка была закончена на устройстве %s",
    "Authentication" : "Аутентификация",
    "Unknown filetype" : "Неизвестный тип файла",
    "Invalid image" : "Изображение повреждено",
    "Avatar image is not square" : "Изображение аватара не квадратное",
    "today" : "сегодня",
    "tomorrow" : "завтра",
    "yesterday" : "вчера",
    "_in %n day_::_in %n days_" : ["через %n день","через %n дня","через %n дней","через %n день"],
    "_%n day ago_::_%n days ago_" : ["%n день назад","%n дня назад","%n дней назад","%n дней назад"],
    "next month" : "следующий месяц",
    "last month" : "в прошлом месяце",
    "_in %n month_::_in %n months_" : ["через %n месяц","через %n месяца","через %n месяцев","через %n месяц"],
    "_%n month ago_::_%n months ago_" : ["%n месяц назад","%n месяца назад","%n месяцев назад","%n месяцев назад"],
    "next year" : "следующий год",
    "last year" : "в прошлом году",
    "_in %n year_::_in %n years_" : ["через %n год","через %n года","через %n лет","через %n год"],
    "_%n year ago_::_%n years ago_" : ["%n год назад","%n года назад","%n лет назад","%n лет назад"],
    "_in %n hour_::_in %n hours_" : ["через %n час","через %n часа","через %n часов","через %n час"],
    "_%n hour ago_::_%n hours ago_" : ["%n час назад","%n часа назад","%n часов назад","%n часов назад"],
    "_in %n minute_::_in %n minutes_" : ["через %n минуту","через %n минуты","через %n минут","через %n минуту"],
    "_%n minute ago_::_%n minutes ago_" : ["%n минута назад","%n минуты назад","%n минут назад","%n минут назад"],
    "in a few seconds" : "через несколько секунд",
    "seconds ago" : "менее минуты",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль с ID «%s» не существует. Включите его в настройках приложений или обратитесь к администратору.",
    "File name is a reserved word" : "Имя файла является зарезервированным словом",
    "File name contains at least one invalid character" : "Имя файла содержит по крайней мере один некорректный символ",
    "File name is too long" : "Имя файла слишком длинное.",
    "Dot files are not allowed" : "Файлы начинающиеся с точки не допускаются",
    "Empty filename is not allowed" : "Пустое имя файла не допускается",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Приложение «%s» не может быть установлено, так как файл с информацией о приложении не может быть прочтен.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Приложение «%s» не может быть установлено, потому что оно несовместимо с этой версией сервера",
    "__language_name__" : "Русский",
    "This is an automatically sent email, please do not reply." : "Это соощение отправлено автоматически, пожалуйста, не отвечайте на него.",
    "Help" : "Помощь",
    "Apps" : "Приложения",
    "Settings" : "Настройки",
    "Log out" : "Выйти",
    "Users" : "Пользователи",
    "Unknown user" : "Неизвестный пользователь",
    "Overview" : "Общие сведения",
    "Basic settings" : "Основные параметры",
    "Sharing" : "Общий доступ",
    "Security" : "Безопасность",
    "Groupware" : "ПО совместного использования",
    "Additional settings" : "Дополнительные настройки",
    "Personal info" : "Личная информация",
    "Mobile & desktop" : "Клиенты для ПК и мобильных устройств",
    "%s enter the database username and name." : "%s укажите имя пользователя и название для базы данных.",
    "%s enter the database username." : "%s введите имя пользователя базы данных.",
    "%s enter the database name." : "%s введите имя базы данных.",
    "%s you may not use dots in the database name" : "%s Вы не можете использовать точки в имени базы данных",
    "Oracle connection could not be established" : "Соединение с Oracle не может быть установлено",
    "Oracle username and/or password not valid" : "Неверное имя пользователя и/или пароль Oracle",
    "PostgreSQL username and/or password not valid" : "Неверное имя пользователя и/или пароль PostgreSQL",
    "You need to enter details of an existing account." : "Необходимо уточнить данные существующего акаунта.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не поддерживается и %s может работать некорректно на данной платформе. Используйте на свой страх и риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Пожалуйста, удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
    "Set an admin username." : "Задать имя пользователя для администратора.",
    "Set an admin password." : "Задать пароль для admin.",
    "Can't create or write into the data directory %s" : "Невозможно создать или записать в каталог данных %s",
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бэкенд общего доступа %s должен реализовывать интерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Механизм предоставления общего доступа %s не найден",
    "Sharing backend for %s not found" : "Не найден механизм предоставления общего доступа для %s ",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s предоставил(а) вам доступ к «%2$s» и хочет добавить:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s предоставил(а) вам доступ к «%2$s» и хочет добавить",
    "»%s« added a note to a file shared with you" : "%s добавил(а) примечание к файлу, к которому вам открыт доступ",
    "Open »%s«" : "Открыть «%s»",
    "%1$s via %2$s" : "%1$s через %2$s",
    "You are not allowed to share %s" : "Вам не разрешено делиться %s",
    "Can’t increase permissions of %s" : "Невозможно увеличить права доступа для %s",
    "Files can’t be shared with delete permissions" : "Файлы не могут иметь общий доступ с правами на удаление",
    "Files can’t be shared with create permissions" : "Файлы не могут иметь общий доступ с правами на создание",
    "Expiration date is in the past" : "Дата окончания срока действия уже прошла",
    "Can’t set expiration date more than %s days in the future" : "Невозможно установить дату окончания срока действия более %s дней",
    "%1$s shared »%2$s« with you" : "%1$s предоставил(а) вам доступ к «%2$s»",
    "%1$s shared »%2$s« with you." : "%1$s предоставил(а) вам доступ к «%2$s».",
    "Click the button below to open it." : "Нажмите расположенную ниже кнопку для перехода к полученному общему ресурсу.",
    "The requested share does not exist anymore" : "Запрошенный общий ресурс более не существует.",
    "Could not find category \"%s\"" : "Категория «%s»  не найдена",
    "Sunday" : "Воскресенье",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sun." : "Вс.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Вс",
    "Mo" : "Пн",
    "Tu" : "Вт",
    "We" : "Ср",
    "Th" : "Чт",
    "Fr" : "Пт",
    "Sa" : "Сб",
    "January" : "Январь",
    "February" : "Февраль",
    "March" : "Март",
    "April" : "Апрель",
    "May" : "Май",
    "June" : "Июнь",
    "July" : "Июль",
    "August" : "Август",
    "September" : "Сентябрь",
    "October" : "Октябрь",
    "November" : "Ноябрь",
    "December" : "Декабрь",
    "Jan." : "Янв.",
    "Feb." : "Фев.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Май",
    "Jun." : "Июн.",
    "Jul." : "Июл.",
    "Aug." : "Авг.",
    "Sep." : "Сен.",
    "Oct." : "Окт.",
    "Nov." : "Нояб.",
    "Dec." : "Дек.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "В составе имени пользователя допускаются следующие символы: «a–z», «A–Z», «0–9» и «_.@-'»",
    "A valid username must be provided" : "Укажите допустимое имя пользователя",
    "Username contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробел в начале или в конце",
    "Username must not consist of dots only" : "Имя пользователя должно состоять не только из точек",
    "A valid password must be provided" : "Укажите допустимый пароль",
    "The username is already being used" : "Имя пользователя уже используется",
    "Could not create user" : "Не удалось создать пользователя",
    "User disabled" : "Пользователь отключен",
    "Login canceled by app" : "Вход отменен приложением",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложение «%1$s» не может быть установлено, так как не удовлетворены следующие зависимости: %2$s",
    "a safe home for all your data" : "надёжный дом для всех ваших данных",
    "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
    "Can't read file" : "Не удается прочитать файл",
    "Application is not enabled" : "Приложение не разрешено",
    "Authentication error" : "Ошибка аутентификации",
    "Token expired. Please reload page." : "Токен просрочен. Перезагрузите страницу.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не установлены драйвера баз данных (sqlite, mysql или postgresql)",
    "Cannot write into \"config\" directory" : "Запись в каталог «config» невозможна",
    "Cannot write into \"apps\" directory" : "Запись в каталог «app» невозможна",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в каталог приложений или отключив магазин приложений в файле конфигурации. Смотрите %s",
    "Cannot create \"data\" directory" : "Невозможно создать каталог «data»",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в корневой каталог. Смотрите %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Разрешения обычно можно исправить, предоставив веб-серверу право на запись в корневой каталог. Смотрите %s.",
    "Setting locale to %s failed" : "Установка локали %s не удалась",
    "Please install one of these locales on your system and restart your webserver." : "Установите один из этих языковых пакетов на вашу систему и перезапустите веб-сервер.",
    "Please ask your server administrator to install the module." : "Попросите администратора сервера установить этот модуль.",
    "PHP module %s not installed." : "Не установлен PHP-модуль %s.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметру PHP «%s» не присвоено значение «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Настройка этого параметра в файле php.ini восстановит работоспособность Nextcloud",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload установлен в «%s», при этом требуется «0»",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Чтобы исправить эту проблему установите параметр <code>mbstring.func_overload</code> в значение <code>0</code> в php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Требуется как минимум libxml2 версии 2.7.0. На данный момент установлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Для исправления этой ошибки обновите версию libxml2 и перезапустите ваш веб-сервер.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Очевидно, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модули PHP были установлены, но они все еще перечислены как недостающие?",
    "Please ask your server administrator to restart the web server." : "Пожалуйста, попросите вашего администратора перезапустить веб-сервер.",
    "PostgreSQL >= 9 required" : "Требуется PostgreSQL >= 9",
    "Please upgrade your database version" : "Обновите базу данных",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Измените права доступа на 0770, чтобы другие пользователи не могли получить список файлов этого каталога.",
    "Your data directory is readable by other users" : "Каталог данных доступен для чтения другим пользователям",
    "Your data directory must be an absolute path" : "Каталог данных должен быть указан в виде абсолютного пути",
    "Check the value of \"datadirectory\" in your configuration" : "Проверьте в значение параметра «datadirectory» в файле конфигурации.",
    "Your data directory is invalid" : "Каталог данных не верен",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Убедитесь, что в корне каталога данных присутствует файл «.ocdata».",
    "Action \"%s\" not supported or implemented." : "Действие «%s» не поддерживается или не реализовано.",
    "Authentication failed, wrong token or provider ID given" : "Ошибка аутентификации, неверный токен или идентификатор провайдера",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Отсутствуют параметры для завершения запроса. Отсутствующие параметры: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Идентификатор «%1$s» уже поставщиком услуг межсерверного обмена «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Провайдер облачной федерации с идентификатором: \"%s\" не существует.",
    "Could not obtain lock type %d on \"%s\"." : "Не удалось получить блокировку типа %d для «%s»",
    "Storage unauthorized. %s" : "Хранилище неавторизовано. %s",
    "Storage incomplete configuration. %s" : "Неполная конфигурация хранилища.  %s",
    "Storage connection error. %s" : "Ошибка подключения к хранилищу. %s",
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
    "Create" : "Создание",
    "Change" : "Изменение",
    "Delete" : "Удаление",
    "Share" : "Предоставление доступа",
    "Unlimited" : "Неограничено",
    "Verifying" : "Производится проверка",
    "Verifying …" : "Производится проверка…",
    "Verify" : "Проверить",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Не удалось поделиться %s, так как механизм хранения не допускает публикации из элементов типа %i",
    "Sharing %s failed, because the file does not exist" : "Не удалось поделиться %s, файл не существует",
    "Sharing %s failed, because you can not share with yourself" : "Не удалось поделиться %s. Вы не можете поделиться с самим собой.",
    "Sharing %1$s failed, because the user %2$s does not exist" : "Не удалось предоставить общий доступ к «%1$s», пользователь %2$s не существует.",
    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Не удалось предоставить доступ к «%1$s» , так как пользователь %2$s не состоит в какой-либо группе, в которой состоит %3$s",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Не удалось предоставить общий доступ к «%1$s» , пользователю %2$s такой доступ уже предоставлен.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Не удалось предоставить доступ к «%1$s», так как этот ресурс уже доступен пользователю %2$s",
    "Sharing %1$s failed, because the group %2$s does not exist" : "Не удалось предоставить доступ к «%1$s», группа %2$s не существует",
    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Не удалось предоставить доступ к «%1$s», пользователь %2$s не является участником группы %3$s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Вам нужно задать пароль для создания публичной ссылки. Разрешены только защищённые ссылки",
    "Sharing %s failed, because sharing with links is not allowed" : "Не удалось поделиться %s, открытие доступа по ссылке запрещено",
    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Не удалось предоставить доступ к «%1$s», не удалось найти %2$s, возможно, сервер не доступен.",
    "Share type %1$s is not valid for %2$s" : "Тип общего доступа «%1$s» недопустим для «%2$s»",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Невозможно установить дату истечения. Общие ресурсы не могут устареть позже %s с момента их публикации.",
    "Cannot set expiration date. Expiration date is in the past" : "Невозможно установить дату окончания. Дата окончания в прошлом.",
    "Sharing failed, because the user %s is the original sharer" : "Не удалось поделиться, потому что пользователь %s владелец этого элемента",
    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Не удалось предоставить доступ к «%1$s», прав %2$s недостаточно",
    "Sharing %s failed, because resharing is not allowed" : "Не удалось поделиться %s, повторное открытие доступа запрещено",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Не удалось предоставить доступ к «%1$s», механизм предоставления общего доступа не смог определить путь к «%2$s»",
    "Sharing %s failed, because the file could not be found in the file cache" : "Не удалось поделиться %s, элемент не найден в файловом кеше."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
